@@ -7,7 +7,7 @@
  * 	Istituto Nazionale di Geofisica e Vulcanologia - Italy
  *	quintiliani@ingv.it
  *
- * $Id: nmxp.c,v 1.7 2010/03/25 13:25:46 quintiliani Exp $
+ * $Id: nmxp.c 4165 2011-01-24 15:19:28Z quintiliani $
  *
  */
 
@@ -206,8 +206,8 @@ int nmxp_sendAddTimeSeriesChannel(int isock, NMXP_CHAN_LIST_NET *channelList, in
 			snprintf(s_channels, MAX_LEN_S_CHANNELS, "%.0f/%d chan %d of %d:",
 				(double)diff_usec/1000.0, split_channelList.number, i, channelList->number);
 			    for(j=0; j < split_channelList.number; j++) {
-				strncat(s_channels, " ", MAX_LEN_S_CHANNELS);
-				strncat(s_channels, NMXP_LOG_STR(split_channelList.channel[j].name), MAX_LEN_S_CHANNELS);
+				strncat(s_channels, " ", MAX_LEN_S_CHANNELS - strlen(s_channels));
+				strncat(s_channels, NMXP_LOG_STR(split_channelList.channel[j].name), MAX_LEN_S_CHANNELS - strlen(s_channels));
 			    }
 			    nmxp_log(NMXP_LOG_NORM, NMXP_LOG_D_CONNFLOW, "%s\n", s_channels);
 			    ret = nmxp_sendAddTimeSeriesChannel_raw(isock, &split_channelList, shortTermCompletion, out_format, buffer_flag);
@@ -467,6 +467,19 @@ int nmxp_sendDataRequest(int isock, int32_t key, int32_t start_time, int32_t end
 }
 
 
+int nmxp_sendRequestPending(int isock) {
+    int ret;
+
+    ret = nmxp_sendMessage(isock, NMXP_MSG_REQUESTPENDING, NULL, 0);
+
+    if(ret != NMXP_SOCKET_OK) {
+	nmxp_log(NMXP_LOG_ERR, NMXP_LOG_D_CONNFLOW, "Send a RequestPending message\n");
+    }
+
+    return ret;
+}
+
+
 NMXP_CHAN_LIST *nmxp_getAvailableChannelList(char * hostname, int portnum, NMXP_DATATYPE datatype, int (*func_cond)(void)) {
     int naqssock;
     NMXP_CHAN_LIST *channelList = NULL, *channelList_subset = NULL;
