@@ -1,4 +1,4 @@
-#pragma ident "$Id: ad.c,v 1.1 2004/03/16 23:17:19 kohler Exp $"
+#pragma ident "$Id: ad.c 1331 2004-03-16 23:32:39Z kohler $"
 /*======================================================================
  *
  *  Decode an AD packet
@@ -14,7 +14,7 @@ BOOL reftek_ad(struct reftek_ad *dest, UINT8 *src)
 
 /* Revision History
  *
- * $Log: ad.c,v $
+ * $Log$
  * Revision 1.1  2004/03/16 23:17:19  kohler
  * Initial revision
  *
